config

package
v0.0.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 17, 2026 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type AnalysisConfig added in v0.0.2

type AnalysisConfig struct {
	MatchingGroups []string `yaml:"matching_groups"`
}

AnalysisConfig controls the analytics view behavior.

type Config

type Config struct {
	Instrument InstrumentConfig `yaml:"instrument"`
	Analysis   AnalysisConfig   `yaml:"analysis"`
}

Config represents .go-trace.yaml.

func Default

func Default() Config

Default returns a config that instruments all Go files.

func Load

func Load(path string) (Config, error)

Load reads and parses a .go-trace.yaml file.

func (Config) Match

func (c Config) Match(path string) bool

Match reports whether the given relative file path matches any of the include patterns.

type InstrumentConfig

type InstrumentConfig struct {
	Include []string `yaml:"include"`
}

InstrumentConfig controls which files are instrumented.

Jump to