Documentation
¶
Overview ¶
Package instrument rewrites Go source files to insert tracing calls.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Injector ¶
type Injector struct {
// contains filtered or unexported fields
}
Injector walks a Go project, rewrites matching files with tracing instrumentation, and writes the result to a temporary directory.
func NewInjector ¶
NewInjector creates an injector with the given config.
Click to show internal directories.
Click to hide internal directories.