package
Version:
v0.0.5
Opens a new window with list of versions in this module.
Published: Mar 17, 2026
License: MIT
Opens a new window with license information.
Imports: 9
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
AppExitMsg is sent when the trace source disconnects.
Bridge connects the tracer collector to the TUI via bubbletea messages.
NewBridge creates a bridge that sends trace trees to the TUI program.
OnSpan handles a completed span. When the root arrives,
builds the tree and sends it to the TUI.
type ErrorMsg struct {
Err error
}
ErrorMsg is sent when the view client encounters an error.
Model is the bubbletea model for the go-trace TUI.
New creates a new TUI model.
Err returns the error that caused the TUI to exit, if any.
Init implements tea.Model.
Update implements tea.Model.
View implements tea.Model.
TraceMsg is sent when a complete trace tree is ready.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.